'use client';

import { useState } from 'react';
import Image from 'next/image';
import { motion } from 'framer-motion';
import MD5 from 'crypto-js/md5'

import blahaj from '../../public/blahaj.webp';
import gitlab from '../../public/gitlab.svg';
import picrew from '../../public/picrew.png';


export default function Home() {
  const [COTD, setCOTD] = useState(false);
  const date = new Date();
  const [day, month, year] = [
    date.getDate(),
    date.getMonth() + 1,
    date.getFullYear(),
  ];

  const hash = MD5(`${day}.${month}.${year}`)
  const [C, M, Y, K] = hash.words.map(x => (x + 2 ** 31) / (2 ** 32));

  const R = Math.round(255 * (1 - C) * (1 - K));
  const G = Math.round(255 * (1 - M) * (1 - K));
  const B = Math.round(255 * (1 - Y) * (1 - K));

  const RGB = R.toString(16).padStart(2, '0') + G.toString(16).padStart(2, '0') + B.toString(16).padStart(2, '0');

  const items = [
    {
      name: 'eParafia',
      class_: 'hover:border-[#466e83] hover:bg-[#365e70]',
      link: 'https://eparafia.eu',
    },
    {
      name: 'Podlaski ZBS',
      class_: 'hover:border-[#7c626c] hover:bg-[#6f6f71]',
      link: 'https://podlaskizbs.pl',
    },
    {
      name: 'Ikubi',
      class_: 'hover:border-[#7c626c] hover:bg-[#6f6f71]',
      link: 'https://ikubi.pl',
    },
    {
      name: 'nyaa',
      class_: 'hover:border-[#466e83] hover:bg-[#365e70]',
      git: 'https://gitlab.com/yaemiku/nyaa',
      desc: `it's a script, dummy!`,
    },
    {
      name: 'Puchar LO V',
      class_: 'hover:border-[#7f7f84] hover:bg-[#6f6f71]',
      link: 'https://puchar.lo5.bielsko.pl',
      git: 'https://gitlab.com/yaemiku/puchar',
      full: true,
    },
  ];

  return (
    <div className="max-w-screen-md mx-auto prose mt-big p-small prose-zinc prose-invert">
      <header className="flex flex-col items-center justify-around px-base">
        <div>
          <motion.div
            animate={{
              left: 0,
              right: 0,
            }}
            className="absolute z-10 flex flex-col h-16 shadow-2xl max-w-vw my-28"
          >
            <div className="z-0 grow bg-trans-blue"></div>
            <div className="z-0 grow bg-trans-pink"></div>
            <div className="z-0 bg-white grow"></div>
            <div className="z-0 grow bg-trans-pink"></div>
            <div className="z-0 grow bg-trans-blue"></div>
          </motion.div>
          <div className="relative z-20 mx-auto w-72">
            <Image
              src={picrew}
              alt="My Picrew"
              className="rounded-full shadow-2xl pointer-events-none select-none"
              priority
            />
          </div>
        </div>
        <div className="flex flex-col items-center w-full my-base gap-small mt-big">
          <h1 className="flex text-3xl select-none mb-none gap-small">
            <span className="my-auto">
              <a
                href="https://www.youtube.com/watch?v=WzZPPXfYSvE"
                className="no-underline"
                target="_blank"
              >
                🐀&nbsp;
              </a>
            </span>
            <div className="flex flex-col text-center">
              <span className=''>Nikola Kubiczek</span>
              <span className="text-xs font-semibold text-zinc-500">
                (she/her)
              </span>
            </div>
            <span className="my-auto">
              <a
                href="https://www.youtube.com/watch?v=JsV8EI3c48M"
                className="no-underline"
                target="_blank"
              >
                &nbsp;🦈
              </a>
            </span>
          </h1>
          <b className="font-jetbrains">
            <p className="flex flex-col items-center font-light my-none text-lime-50">
              <span>me<span className='mx-xs'>@</span>yaemiku.dev</span>
              <a href="public.asc" target="_blank">
                pgp key
              </a>
              <span className="text-xs mt-small">click on the emojis !!</span>
            </p>
          </b>
        </div>
      </header>
      <main className="flex flex-col items-center justify-around px-4">
        <figure className="flex flex-col max-w-screen-sm my-big gap-big">
          <blockquote className="text-2xl text-center text-transparent bg-clip-text bg-gradient-to-br from-trans-blue via-trans-pink to-white">
            Why be serious when you can just be silly ???
          </blockquote>

          <div className="grid text-sm gap-base md:grid-cols-2 font-jetbrains">
            <div className="text-center transition ease-in-out border rounded-md transform-gpu col-span-full p-small border-zinc-700 bg-gradient-to-r from-bi-red via-bi-violet to-bi-blue">
              <h1 className="font-semibold">My blog !!</h1>
              <a href="https://blog.yaemiku.dev" target="_blank">
                https://blog.yaemiku.dev
              </a>
            </div>
            {items.map(({ name, class_, link, git, full, desc }, i) => (
              <div
                className={`${git ? 'flex' : ''
                  } transition transform-gpu ease-in-out p-small rounded-md ${!!full ? 'col-span-full' : ''
                  } border border-zinc-700 bg-zinc-800 ${class_}`}
                key={i}
              >
                {git ? (
                  <>
                    <div>
                      <h1 className="font-semibold">{name}</h1>
                      {link ? (
                        <a href={link} target="_blank">
                          {link}
                        </a>
                      ) : (
                        <span>{desc}</span>
                      )}
                    </div>

                    <a href={git} className="my-auto ml-auto" target="_blank">
                      <Image src={gitlab} alt="gitlab" className="w-8 h-8" />
                    </a>
                  </>
                ) : (
                  <>
                    <h1 className="font-semibold">{name}</h1>
                    <a href={link} target="_blank">
                      {link}
                    </a>
                  </>
                )}
              </div>
            ))}
            <div
              style={{ backgroundColor: `#${RGB}` }}
              onClick={() => setCOTD(!COTD)}
              title='How does it work?'
              className="flex flex-col items-center col-span-full p-small rounded-md border border-zinc-700 hover:border-[#7f7f84] cursor-pointer"
            >
              <motion.a className="font-semibold">Color of the day!</motion.a>
              <motion.div
                animate={COTD ? "open" : "closed"}
                initial="closed"
                variants={{
                  open: { opacity: 1, display: "block", margin: "0.5rem 0" },
                  closed: { opacity: 0, display: "none" }
                }}
              >
                <div className='flex flex-col items-center gap-small'>
                  <span>Take the current date:</span>
                  <span className='font-semibold'>{day}.{month}.{year}</span>
                  <span>Apply MD5:</span>
                  <span className='font-semibold'>{hash.toString()}</span>
                  <span className='max-w-xs text-center'>Finally, separate this hash into 4 uint32 words, divide them by 2^32 and you&apos;re good to go :{')'}</span>

                </div>
              </motion.div>
              <span>
                C: <span className="font-semibold">{Math.round(C * 100)}%</span>{' '}
                M: <span className="font-semibold">{Math.round(M * 100)}%</span>{' '}
                Y: <span className="font-semibold">{Math.round(Y * 100)}%</span>{' '}
                K: <span className="font-semibold">{Math.round(K * 100)}%</span>
              </span>
              <span>
                R: <span className="font-semibold">{R}</span> G:{' '}
                <span className="font-semibold">{G}</span> B:{' '}
                <span className="font-semibold">{B}</span>
              </span>
            </div>
          </div>

          <Image
            src={blahaj}
            alt="blahaj"
            className="mx-auto rounded-md mt-big"
          />
          <figcaption className="mt-[-1.25em] text-xs text-center text-zinc-400">
            u/markyminkk on r/BLAHAJ
          </figcaption>
        </figure>
      </main>
      <footer className="text-center my-small">
        <em>
          <a href="https://gitlab.com/yaemiku" target="_blank">
            yaemiku
          </a>{' '}
          &copy; <span id="year">2023</span>
        </em>
        <br />

        <em>
          Made with{' '}
          <a href="https://nextjs.org" target="_blank">
            NextJS
          </a>
          ,{' '}
          <a href="https://framer.com" target="_blank">
            Framer Motion
          </a>{' '}
          and{' '}
          <a href="https://tailwindcss.com" target="_blank">
            TailwindCSS
          </a>{' '}
        </em>
        <br />
        <em>
          Link to{' '}
          <a href="https://picrew.me/image_maker/599056" target="_blank">
            picrew
          </a>
        </em>
        <figure className="max-w-screen-md select-none my-big">
          <blockquote className="text-xs text-justify text-zinc-400">
            Oh, wretched memory that compels us to remember the paths we took to
            arrive at the present state of affairs! Further: as I lay awake but
            still half dreaming, I felt that my body was not homogeneous, that
            some parts were still those of a boy, and that my head was laughing
            at my leg and ridiculing it, that my leg was laughing at my head,
            that my finger was poking fun at my heart, my heart at my brain,
            that my nose was thumbing itself at my eye, my eye chuckling and
            bellowing at my nose — and all my parts were wildly raping each
            other in an all-encompassing and piercing state of pan-mockery. Nor
            did my fear lessen one iota when I reached full consciousness and
            began reflecting on my life. On the contrary, it intensified even as
            it was interrupted (or accentuated) by a giggle my mouth could not
            hold back. I was halfway down the path of my life when I found
            myself in a dark forest.
          </blockquote>
          <figcaption className="text-xs text-right mt-small text-zinc-700">
            ——— Witold Gombrowicz, Ferdydurke
          </figcaption>
        </figure>
      </footer>
    </div>
  );
}
